@@ -53,8 +53,10 @@ data Config = Config {
     , cfgReport       :: Last FilePath -- ^ Filename of report.
     , cfgSamples      :: Last Int    -- ^ Number of samples to collect.
     , cfgSummaryFile  :: Last FilePath -- ^ Filename of summary CSV.
+    , cfgCompareFile  :: Last FilePath -- ^ Filename of the comparison CSV.
     , cfgTemplate     :: Last FilePath -- ^ Filename of report template.
     , cfgVerbosity    :: Last Verbosity -- ^ Whether to run verbosely.
+    , cfgJUnitFile    :: Last FilePath -- ^ Filename of JUnit report.
     } deriving (Eq, Read, Show, Typeable)
 
 instance Monoid Config where
@@ -72,8 +74,10 @@ defaultConfig = Config {
                 , cfgReport       = mempty
                 , cfgSamples      = ljust 100
                 , cfgSummaryFile  = mempty
+                , cfgCompareFile  = mempty
                 , cfgTemplate     = ljust "report.tpl"
                 , cfgVerbosity    = ljust Normal
+                , cfgJUnitFile    = mempty
                 }
 
 -- | Constructor for 'Last' values.
@@ -98,8 +102,10 @@ emptyConfig = Config {
               , cfgResamples    = mempty
               , cfgSamples      = mempty
               , cfgSummaryFile  = mempty
+              , cfgCompareFile  = mempty
               , cfgTemplate     = mempty
               , cfgVerbosity    = mempty
+              , cfgJUnitFile    = mempty
               }
 
 appendConfig :: Config -> Config -> Config
@@ -113,7 +119,9 @@ appendConfig a b =
     , cfgResamples    = app cfgResamples a b
     , cfgSamples      = app cfgSamples a b
     , cfgSummaryFile  = app cfgSummaryFile a b
+    , cfgCompareFile  = app cfgCompareFile a b
     , cfgTemplate     = app cfgTemplate a b
     , cfgVerbosity    = app cfgVerbosity a b
+    , cfgJUnitFile    = app cfgJUnitFile a b
     }
   where app f = mappend `on` f
